@@ -1,19 +1,23 @@
-
-from PyObjCTools.TestSupport import *
 import CoreServices
+from PyObjCTools.TestSupport import TestCase
 
-class TestSKDocument (TestCase):
+
+class TestSKDocument(TestCase):
     def testTypes(self):
         self.assertIsCFType(CoreServices.SKDocumentRef)
 
     def testFunctions(self):
-        self.assertIsInstance(CoreServices.SKDocumentGetTypeID(), (int,  long))
+        self.assertIsInstance(CoreServices.SKDocumentGetTypeID(), int)
 
         self.assertResultIsCFRetained(CoreServices.SKDocumentCreateWithURL)
         ref = CoreServices.SKDocumentCreateWithURL(
-                    CoreServices.CFURLCreateWithFileSystemPath(
-                        None, b"/Library/Documentation/Acknowledgements.rtf".decode('latin1'),
-                        CoreServices.kCFURLPOSIXPathStyle, False))
+            CoreServices.CFURLCreateWithFileSystemPath(
+                None,
+                "/Library/Documentation/Acknowledgements.rtf",
+                CoreServices.kCFURLPOSIXPathStyle,
+                False,
+            )
+        )
         self.assertIsInstance(ref, CoreServices.SKDocumentRef)
 
         self.assertResultIsCFRetained(CoreServices.SKDocumentCopyURL)
@@ -21,19 +25,14 @@ class TestSKDocument (TestCase):
         self.assertIsInstance(v, CoreServices.CFURLRef)
 
         self.assertResultIsCFRetained(CoreServices.SKDocumentCreate)
-        ref2 = CoreServices.SKDocumentCreate(
-                None, ref, "foobar")
+        ref2 = CoreServices.SKDocumentCreate(None, ref, "foobar")
         self.assertIsInstance(ref2, CoreServices.SKDocumentRef)
 
         v = CoreServices.SKDocumentGetSchemeName(ref)
-        self.assertIsInstance(v, unicode)
+        self.assertIsInstance(v, str)
 
         v = CoreServices.SKDocumentGetName(ref)
-        self.assertIsInstance(v, unicode)
+        self.assertIsInstance(v, str)
 
         v = CoreServices.SKDocumentGetParent(ref2)
-        self.failUnless(v is ref)
-
-
-if __name__ == "__main__":
-    main()
+        self.assertTrue(v is ref)
